package javax.swing;

import javax.accessibility.AccessibleState;
import javax.accessibility.AccessibleStateSet;
import java.awt.Container;
import java.awt.LayoutManager;
import java.awt.Component;
import java.awt.Graphics;
import java.awt.event.WindowEvent;
import sun.awt.SunToolkit;
import java.awt.Window;
import java.awt.GraphicsConfiguration;
import java.awt.Frame;
import javax.accessibility.AccessibleContext;
import javax.accessibility.Accessible;
import java.awt.Dialog;

public class JDialog extends Dialog implements WindowConstants, Accessible, RootPaneContainer, TransferHandler.HasGetTransferHandler
{
    private static final Object defaultLookAndFeelDecoratedKey;
    private int defaultCloseOperation;
    protected JRootPane rootPane;
    protected boolean rootPaneCheckingEnabled;
    private TransferHandler transferHandler;
    protected AccessibleContext accessibleContext;
    
    public JDialog() {
        this((Frame)null, false);
    }
    
    public JDialog(Frame frame) {
        this(frame, false);
    }
    
    public JDialog(Frame frame, boolean b) {
        this(frame, "", b);
    }
    
    public JDialog(Frame frame, String s) {
        this(frame, s, false);
    }
    
    public JDialog(Frame frame, String title, boolean modal) {
        super((frame == null) ? SwingUtilities.getSharedOwnerFrame() : frame, title, modal);
        this.defaultCloseOperation = 1;
        this.rootPaneCheckingEnabled = false;
        this.accessibleContext = null;
        if (frame == null) {
            this.addWindowListener(SwingUtilities.getSharedOwnerFrameShutdownListener());
        }
        this.dialogInit();
    }
    
    public JDialog(Frame frame, String title, boolean modal, GraphicsConfiguration gc) {
        super((frame == null) ? SwingUtilities.getSharedOwnerFrame() : frame, title, modal, gc);
        this.defaultCloseOperation = 1;
        this.rootPaneCheckingEnabled = false;
        this.accessibleContext = null;
        if (frame == null) {
            this.addWindowListener(SwingUtilities.getSharedOwnerFrameShutdownListener());
        }
        this.dialogInit();
    }
    
    public JDialog(Dialog dialog) {
        this(dialog, false);
    }
    
    public JDialog(Dialog dialog, boolean b) {
        this(dialog, "", b);
    }
    
    public JDialog(Dialog dialog, String s) {
        this(dialog, s, false);
    }
    
    public JDialog(Dialog owner, String title, boolean modal) {
        super(owner, title, modal);
        this.defaultCloseOperation = 1;
        this.rootPaneCheckingEnabled = false;
        this.accessibleContext = null;
        this.dialogInit();
    }
    
    public JDialog(Dialog owner, String title, boolean modal, GraphicsConfiguration gc) {
        super(owner, title, modal, gc);
        this.defaultCloseOperation = 1;
        this.rootPaneCheckingEnabled = false;
        this.accessibleContext = null;
        this.dialogInit();
    }
    
    public JDialog(Window window) {
        this(window, Dialog.ModalityType.MODELESS);
    }
    
    public JDialog(Window window, Dialog.ModalityType modalityType) {
        this(window, "", modalityType);
    }
    
    public JDialog(Window window, String s) {
        this(window, s, Dialog.ModalityType.MODELESS);
    }
    
    public JDialog(Window owner, String title, Dialog.ModalityType modalityType) {
        super(owner, title, modalityType);
        this.defaultCloseOperation = 1;
        this.rootPaneCheckingEnabled = false;
        this.accessibleContext = null;
        this.dialogInit();
    }
    
    public JDialog(Window owner, String title, Dialog.ModalityType modalityType, GraphicsConfiguration gc) {
        super(owner, title, modalityType, gc);
        this.defaultCloseOperation = 1;
        this.rootPaneCheckingEnabled = false;
        this.accessibleContext = null;
        this.dialogInit();
    }
    
    protected void dialogInit() {
        this.enableEvents(72L);
        this.setLocale(JComponent.getDefaultLocale());
        this.setRootPane(this.createRootPane());
        this.setBackground(UIManager.getColor("control"));
        this.setRootPaneCheckingEnabled(true);
        if (isDefaultLookAndFeelDecorated() && UIManager.getLookAndFeel().getSupportsWindowDecorations()) {
            this.setUndecorated(true);
            this.getRootPane().setWindowDecorationStyle(2);
        }
        SunToolkit.checkAndSetPolicy(this);
    }
    
    protected JRootPane createRootPane() {
        JRootPane rootPane = new JRootPane();
        rootPane.setOpaque(true);
        return rootPane;
    }
    
    @Override
    protected void processWindowEvent(WindowEvent e) {
        super.processWindowEvent(e);
        if (e.getID() == 201) {
            switch (this.defaultCloseOperation) {
                case 1: {
                    this.setVisible(false);
                    break;
                }
                case 2: {
                    this.dispose();
                    break;
                }
            }
        }
    }
    
    public void setDefaultCloseOperation(int defaultCloseOperation) {
        if (defaultCloseOperation != 0 && defaultCloseOperation != 1 && defaultCloseOperation != 2) {
            throw new IllegalArgumentException("defaultCloseOperation must be one of: DO_NOTHING_ON_CLOSE, HIDE_ON_CLOSE, or DISPOSE_ON_CLOSE");
        }
        this.firePropertyChange("defaultCloseOperation", this.defaultCloseOperation, this.defaultCloseOperation = defaultCloseOperation);
        return;
    }
    
    public int getDefaultCloseOperation() {
        return this.defaultCloseOperation;
    }
    
    public void setTransferHandler(TransferHandler transferHandler) {
        TransferHandler transferHandler2 = this.transferHandler;
        SwingUtilities.installSwingDropTargetAsNecessary(this, this.transferHandler = transferHandler);
        this.firePropertyChange("transferHandler", transferHandler2, transferHandler);
    }
    
    @Override
    public TransferHandler getTransferHandler() {
        return this.transferHandler;
    }
    
    @Override
    public void update(Graphics g) {
        this.paint(g);
    }
    
    public void setJMenuBar(JMenuBar menuBar) {
        this.getRootPane().setMenuBar(menuBar);
    }
    
    public JMenuBar getJMenuBar() {
        return this.getRootPane().getMenuBar();
    }
    
    protected boolean isRootPaneCheckingEnabled() {
        return this.rootPaneCheckingEnabled;
    }
    
    protected void setRootPaneCheckingEnabled(boolean rootPaneCheckingEnabled) {
        this.rootPaneCheckingEnabled = rootPaneCheckingEnabled;
    }
    
    @Override
    protected void addImpl(Component component, Object o, int n) {
        if (this.isRootPaneCheckingEnabled()) {
            this.getContentPane().add(component, o, n);
        }
        else {
            super.addImpl(component, o, n);
        }
    }
    
    @Override
    public void remove(Component component) {
        if (component == this.rootPane) {
            super.remove(component);
        }
        else {
            this.getContentPane().remove(component);
        }
    }
    
    @Override
    public void setLayout(LayoutManager layoutManager) {
        if (this.isRootPaneCheckingEnabled()) {
            this.getContentPane().setLayout(layoutManager);
        }
        else {
            super.setLayout(layoutManager);
        }
    }
    
    @Override
    public JRootPane getRootPane() {
        return this.rootPane;
    }
    
    protected void setRootPane(JRootPane rootPane) {
        if (this.rootPane != null) {
            this.remove(this.rootPane);
        }
        this.rootPane = rootPane;
        if (this.rootPane != null) {
            int rootPaneCheckingEnabled = this.isRootPaneCheckingEnabled();
            try {
                this.setRootPaneCheckingEnabled(false);
                this.add(this.rootPane, "Center");
            }
            finally {
                this.setRootPaneCheckingEnabled((boolean)rootPaneCheckingEnabled);
            }
        }
    }
    
    @Override
    public Container getContentPane() {
        return this.getRootPane().getContentPane();
    }
    
    @Override
    public void setContentPane(Container contentPane) {
        this.getRootPane().setContentPane(contentPane);
    }
    
    @Override
    public JLayeredPane getLayeredPane() {
        return this.getRootPane().getLayeredPane();
    }
    
    @Override
    public void setLayeredPane(JLayeredPane layeredPane) {
        this.getRootPane().setLayeredPane(layeredPane);
    }
    
    @Override
    public Component getGlassPane() {
        return this.getRootPane().getGlassPane();
    }
    
    @Override
    public void setGlassPane(Component glassPane) {
        this.getRootPane().setGlassPane(glassPane);
    }
    
    @Override
    public Graphics getGraphics() {
        JComponent.getGraphicsInvoked(this);
        return super.getGraphics();
    }
    
    @Override
    public void repaint(long tm, int x, int y, int width, int height) {
        if (RepaintManager.HANDLE_TOP_LEVEL_PAINT) {
            RepaintManager.currentManager(this).addDirtyRegion(this, x, y, width, height);
        }
        else {
            super.repaint(tm, x, y, width, height);
        }
    }
    
    public static void setDefaultLookAndFeelDecorated(boolean b) {
        if (b) {
            SwingUtilities.appContextPut(JDialog.defaultLookAndFeelDecoratedKey, Boolean.TRUE);
        }
        else {
            SwingUtilities.appContextPut(JDialog.defaultLookAndFeelDecoratedKey, Boolean.FALSE);
        }
    }
    
    public static boolean isDefaultLookAndFeelDecorated() {
        Boolean false = (Boolean)SwingUtilities.appContextGet(JDialog.defaultLookAndFeelDecoratedKey);
        if (false == null) {
            false = Boolean.FALSE;
        }
        return (boolean)false;
    }
    
    @Override
    protected String paramString() {
        String str;
        if (this.defaultCloseOperation == 1) {
            str = "HIDE_ON_CLOSE";
        }
        else if (this.defaultCloseOperation == 2) {
            str = "DISPOSE_ON_CLOSE";
        }
        else if (this.defaultCloseOperation == 0) {
            str = "DO_NOTHING_ON_CLOSE";
        }
        else {
            str = "";
        }
        return super.paramString() + ",defaultCloseOperation=" + str + ",rootPane=" + ((this.rootPane != null) ? this.rootPane.toString() : "") + ",rootPaneCheckingEnabled=" + (this.rootPaneCheckingEnabled ? "true" : "false");
    }
    
    @Override
    public AccessibleContext getAccessibleContext() {
        if (this.accessibleContext == null) {
            this.accessibleContext = new JDialog.AccessibleJDialog();
        }
        return this.accessibleContext;
    }
    
    static {
        defaultLookAndFeelDecoratedKey = new StringBuffer("JDialog.defaultLookAndFeelDecorated");
    }
    
    protected class AccessibleJDialog extends Dialog.AccessibleAWTDialog
    {
        @Override
        public String getAccessibleName() {
            if (this.accessibleName != null) {
                return this.accessibleName;
            }
            if (JDialog.this.getTitle() == null) {
                return super.getAccessibleName();
            }
            return JDialog.this.getTitle();
        }
        
        @Override
        public AccessibleStateSet getAccessibleStateSet() {
            AccessibleStateSet accessibleStateSet = super.getAccessibleStateSet();
            if (JDialog.this.isResizable()) {
                accessibleStateSet.add(AccessibleState.RESIZABLE);
            }
            if (JDialog.this.getFocusOwner() != null) {
                accessibleStateSet.add(AccessibleState.ACTIVE);
            }
            if (JDialog.this.isModal()) {
                accessibleStateSet.add(AccessibleState.MODAL);
                return accessibleStateSet;
            }
            return accessibleStateSet;
        }
    }
}
